@@ -373,7 +373,12 @@ usercheck(pwquality_settings_t *pwq, const char *new,
           char *user)
 {
         char *f, *b;
-        int dist;
+        int dist, userlen = strlen(user);
+
+        /* No point to check for username in password in 1-3 char
+         * usernames; it will be contained one way or another anyway. */
+        if (userlen < PWQ_MIN_WORD_LENGTH)
+                return 0;
 
         if (strstr(new, user) != NULL)
                 return 1;
@@ -385,7 +390,7 @@ usercheck(pwquality_settings_t *pwq, const char *new,
         /* now reverse the username, we can do that in place
                 as it is strdup-ed */
         f = user;
-        b = user + strlen(user) - 1;
+        b = user + userlen - 1;
         while (f < b) {
                 char c;
 
@@ -553,7 +558,8 @@ password_check(pwquality_settings_t *pwq,
         if (!rv && sequence(pwq, new, auxerror))
                 rv = PWQ_ERROR_MAX_SEQUENCE;
 
-        if (!rv && usermono && usercheck(pwq, newmono, usermono))
+        if (!rv && usermono && pwq->user_check &&
+                usercheck(pwq, newmono, usermono))
                 rv = PWQ_ERROR_USER_CHECK;
 
         if (!rv && user && pwq->gecos_check)
@@ -664,6 +670,9 @@ pwquality_check(pwquality_settings_t *pwq, const char *password,
                 return PWQ_ERROR_SAME_PASSWORD;
         }
 
+        if (pwq->diff_ok == 0)
+                oldpassword = NULL;
+
         score = password_check(pwq, password, oldpassword, user, auxerror);
 
         if (score != 0)
